@@ -458,7 +458,10 @@ def downsample_out_of_memory(full_dataset,
     ## start the ray stuff
     index_lists = get_contiguous_indices(processes,full_dataset.shape[1])
     ray_calls = []
-    ray.init(memory=int(process_mem*1000000000),object_store_memory=int(process_mem*1000000000))
+    try:
+        ray.init(memory=int(process_mem*1000000000),object_store_memory=int(process_mem*1000000000))
+    except:
+        ray.init()
     process_writing_bool = ray.put(np.zeros((processes,),dtype=bool))
     if is_sparse_mat:
         ## this means that it should be a sparse matrix that we can put in shared memory
@@ -481,7 +484,10 @@ def downsample_out_of_memory(full_dataset,
                                                                                    temp_dir = temp_dir))
     ray_responses = ray.get(ray_calls)
     for i in range(10):
-        ray.shutdown(exiting_interpreter=True)
+        try:
+            ray.shutdown(exiting_interpreter=True)
+        except:
+            ray.shutdown()
     ## ray responses are the names of the hdf5 files that the results were written to.
     print("finished individual jobs. Now we'll collate them into a single hdf5 file. (This could take a few min)")
     collate_ray_h5s(ray_responses, index_lists, out_h5_file, full_dataset.shape)
@@ -554,7 +560,10 @@ def downsample(original_dataset,
         if processes == None:
             processes = multiprocessing.cpu_count()
         ray_calls = []
-        ray.init(memory=int(process_mem*1000000000),object_store_memory=int(process_mem*1000000000))
+        try:
+            ray.init(memory=int(process_mem*1000000000),object_store_memory=int(process_mem*1000000000))
+        except:
+            ray.init()
         if sparse:
             ray_out_data = ray.put(csc_matrix((np.shape(full_dataset)[0], np.shape(full_dataset)[1]),dtype=np.int32))
         ray_full_dataset = ray.put(full_dataset)
@@ -569,7 +578,10 @@ def downsample(original_dataset,
             out_data = ray.get(ray_out_data)
         print("took:",time.time()-start,"seconds")
         for i in range(10):
-            ray.shutdown(exiting_interpreter=True)
+            try:
+                ray.shutdown(exiting_interpreter=True)
+            except:
+                ray.shutdown()
             gc.collect()
         if not sparse:
             out_data = ray_dicts_to_array(out_dicts, dicts_are_cols=True)
